@@ -1,4 +1,5 @@
 from .cli import cli
 
+
 if __name__ == "__main__":
-    cli(auto_envvar_prefix="PIPENV")
+    cli()
